#
# spec file for package gdbm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libgdbm6
%define lcompat libgdbm_compat4
Name:           gdbm
Version:        1.24
Release:        1.2
Summary:        GNU dbm key/data database
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.gnu.org/software/gdbm/
Source0:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz.sig
Source2:        baselibs.conf
Source4:        %{name}.keyring
# PATCH-FIX-SUSE: remove the build date from src/version.c
Patch4:         gdbm-no-build-date.patch
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  readline-devel
%lang_package

%description
GNU dbm is a library of database functions that use extensible
hashing and work similar to the standard UNIX dbm. These routines are
provided to a programmer needing to create and manipulate a hashed
database.

The basic use of GDBM is to store key/data pairs in a data file. Each
key must be unique and each key is paired with only one data item.

The library provides primitives for storing key/data pairs, searching
and retrieving the data by its key and deleting a key along with its
data. It also supports sequential iteration over all key/data pairs in
a database.

%package -n %{lname}
Summary:        GNU dbm key/data database
# O/P added in 12.2
License:        GPL-3.0-or-later
Group:          System/Libraries
Obsoletes:      gdbm < %{version}-%{release}
Provides:       gdbm = %{version}-%{release}
# For lang package
Provides:       %{name} = %{version}

%description -n %{lname}
GNU dbm is a library of database functions that use extensible
hashing and work similar to the standard UNIX dbm. These routines are
provided to a programmer needing to create and manipulate a hashed
database.

The basic use of GDBM is to store key/data pairs in a data file. Each
key must be unique and each key is paired with only one data item.

The library provides primitives for storing key/data pairs, searching
and retrieving the data by its key and deleting a key along with its
data. It also supports sequential iteration over all key/data pairs in
a database.

%package -n %{lcompat}
Summary:        GNU dbm key/data database compat wrapper
# Was provided in older sonames
License:        GPL-3.0-or-later
Group:          System/Libraries
Conflicts:      libgdbm4

%description -n %{lcompat}
GNU dbm is a library of database functions that use extensible
hashing and work similar to the standard UNIX dbm. These routines are
provided to a programmer needing to create and manipulate a hashed
database.

This library is providing compatibility wrappers.

%package devel
Summary:        Development files for the dbm key/data database library
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{lcompat} = %{version}
Requires:       %{lname} = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%autosetup -p1

%build

%configure \
  --disable-static \
  --disable-silent-rules \
  --enable-libgdbm-compat \
  --enable-nls \
  --with-readline
%make_build

%check
%make_build check

%install
%make_install
echo "/* GNU ld script
   Use the shared library, but some functions are only in
   the static library, so try that secondarily.  */
GROUP ( %{_libdir}/libgdbm.so %{_libdir}/libgdbm_compat.so )" > %{buildroot}/%{_libdir}/libndbm.so

find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig
%post -n %{lcompat} -p /sbin/ldconfig
%postun -n %{lcompat} -p /sbin/ldconfig

%files lang -f %{name}.lang

%files -n %{lname}
%license COPYING
%{_libdir}/libgdbm.so.*

%files -n %{lcompat}
%license COPYING
%{_libdir}/libgdbm_compat.so.*

%files devel
%doc README NEWS
%{_bindir}/*
%{_includedir}/dbm.h
%{_includedir}/gdbm.h
%{_includedir}/ndbm.h
%{_infodir}/gdbm.info%{?ext_info}
%{_libdir}/libgdbm.so
%{_libdir}/libgdbm_compat.so
%{_libdir}/libndbm.so
%{_mandir}/man1/*%{ext_man}
%{_mandir}/man3/gdbm.3%{?ext_man}

%changelog
* Tue Sep 10 2024 pgajdos@suse.com
- version update to 1.24
  * New gdbm_load option: --update
  * Fix semantics of gdbm_load -r
  * Use getline in gdbmtool shell.
  * New function: gdbm_load_from_file_ext
  * Bugfixes
  * * Fix binary dump format for key and/or data of zero size.
    (see https://puszcza.gnu.org.ua/bugs/?565)
  * * Fix location tracking and recover command in gdbtool.
    (see https://puszcza.gnu.org.ua/bugs/?566)
  * * Fix possible buffer underflow in gdbmload.
  * * Ensure any padding bytes in avail_elem structure are filled with 0.
    (fixes https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1031276)
  * * Improve the documentation.
- modified patches
  %% gdbm-no-build-date.patch (refreshed)
- deleted patches
  - bsc1209583.patch (upstreamed)
* Wed Dec  6 2023 Thorsten Kukuk <kukuk@suse.com>
- libgdbm_compat4: Fix libgdbm version of Conflicts [bsc#1217727]
* Tue Aug  8 2023 Danilo Spinella <danilo.spinella@suse.com>
- Fix bsc#1209583, gdbm_load and gdbm_dump receive a SEGFAULT if
  run without arguments
  bsc1209583.patch
* Sun Feb  6 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.23:
  * Bucket cache switched from balanced tree to hash table
  * Speed up flushing the changed buckets on disk
  * New option codes for gdbm_setopt
  * Enable or disable automatic cache adjustment
- remove obsolete texinfo packaging macros
* Mon Dec 13 2021 pgajdos@suse.com
- version update to 1.22
  * Fix file header validation
  * Fix key verification in sequential access
  * Fix testing with DejaGNU 1.6.3
  * Fix stack overflow in print_usage
  * Fix a leak of avail entry on pushing a new avail block
  * New gdbmtool variables: errorexit, errormask, trace, timing
  * etc. see CHANGES
- modified patches
  %% gdbm-no-build-date.patch (refreshed)
* Mon Aug  9 2021 pgajdos@suse.com
- version update to 1.20
  * New bucket cache
    The bucket cache support has been rewritten from scratch.  The new
    bucket cache code provides for significant speed up of search
    operations.
  * Change mmap prereading strategy
    Pre-reading of the memory mapper regions, introduced in version 1.19
    can be advantageous only when doing intensive look-ups on a read-only
    database.  It degrades performance otherwise, especially if doing
    multiple inserts.  Therefore, this version introduces a new flag
    to gdbm_open: GDBM_PREREAD.  When given, it enables pre-reading of
    memory mapped regions.
- modified patches
  %% gdbm-no-build-date.patch (refreshed)
* Mon Dec 28 2020 pgajdos@suse.com
- version update to 1.19
  * Pre-read the memory mapped regions on systems that support it.
  This speeds up operations on big databases.
  * gdbmtool: tagged initialization of structured data
  Initializers for structured data can be given in tagged form, e.g.:
    store somekey { status=2, id={a,u,x}, name="foo" }
  * Bugfixes:
  * * Preserve locking type during database reorganization
- modified patches
  %% gdbm-no-build-date.patch (refreshed)
- deleted patches
  - gdbm-no-common.patch (upstreamed)
* Sat Feb 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use. Also add a
  explicit %%%%{name] = %%%%{version} Provides to aid supplements to do
  the right thing. We will lose the lang package Recommends for the
  compat package, but normally nobody will have only the compat
  package installed without the current package.
* Mon Jan 20 2020 pgajdos@suse.com
- added patches
  Build with -no-common, [bsc#1160872]
  + gdbm-no-common.patch
* Wed Oct 31 2018 Petr Gajdos <pgajdos@suse.com>
- update to 1.18.1:
  * Fix debian bug 910911: This restores backward compatibility with
    databases created by version 1.8 (and some later versions, with
    mmapped I/O disabled).
* Wed Aug 22 2018 astieger@suse.com
- update to 1.18:
  * Fix directory entry validation
  * Fix improper use of GDBM_DEBUG macro
  * Fix spurious error from gdbm_dump and gdbm_export
  * Make sure gdbm_sync always returns a meaningful value
- includes changes from 1.17:
  * Fix bug in gdbm_dump function, it did not clear the
    GDBM_ITEM_NOT_FOUND error marker, which is set upon its normal
    termination
- changes upstreamed:
  * gdbm_close() and gdbm_sync() now return 0 on success. On error,
    they return -1 and set gdbm_errno and errno to the appropriate
    error codes - drop gdbm-close-and-sync-return-value.patch
* Mon Jul 16 2018 pgajdos@suse.com
- update to 1.16:
  * Fix typo
  * New gdbmtool variables: coalesce and centfree
  * src/falloc.c (avail_lookup): Remove the start parameter.
    (_gdbm_put_av_elem): Rewrite the "can_merge" loop.
- added gdbm-close-and-sync-return-value.patch
  see https://puszcza.gnu.org.ua/bugs/index.php?399
* Sun Jun 17 2018 astieger@suse.com
- update to 1.15:
  * Extensive database consistency checking
  * Improved error checking
  * Removed gdbm-1.8.3 compatibility layer
  * Commands can be given to gdbmtool in the command line
  * Fixed data conversion bugs in storing structured keys or content
  * New member in the gdbm_recovery structure: duplicate_keys
  * New error codes
* Wed May 23 2018 tchvatal@suse.com
- Version update to 1.14.1:
  * Manpage formating issues
  * Make gdbm_error thread-safe
  * Improve database reproducibility
  * Fix build with --enable-gdbm-export
- Rebase patch gdbm-no-build-date.patch
* Fri May 18 2018 jengelh@inai.de
- Fix boilerplate summary.
* Fri May 18 2018 tchvatal@suse.com
- Fix missing dash in baselibs.conf
* Mon May 14 2018 tchvatal@suse.com
- Revert to release 1.13 to allow migration to split compat package
  first. Otherwise OBS can't get heads or tails on conflicts
* Mon May 14 2018 tchvatal@suse.com
- Fix baselibs.conf that got hammered with the compat split from
  main library
* Mon May 14 2018 tchvatal@suse.com
- Put back ndbm compat as the perl testuite seem to have hard time
  without it
- Require both compat and base in develpkg
* Fri May 11 2018 tchvatal@suse.com
- Version update to 1.14.1:
  * Manpage formating issues
  * Make gdbm_error thread-safe
  * Improve database reproducibility
  * Fix build with --enable-gdbm-export
- Rebase patch gdbm-no-build-date.patch
* Tue Mar 27 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
- Move docu to -devel subpackage, where it fits better
* Mon Jul 10 2017 jengelh@inai.de
- Fix RPM groups.
* Wed Jun 28 2017 tchvatal@suse.com
- Version update to 1.13:
  * Various few fixes
- Cleanup the spec a bit
- Refresh patch gdbm-no-build-date.patch
- Remove chinese language support patched in house, if anything it
  should be merged in the upstream git repo
- Drop the ndbm compats as it is not provided by any other distro
* Wed May 18 2016 mpluskal@suse.com
- Update to version 1.12
  * New configuration variable COMPATINCLUDEDIR
- Small spec file cleanups
* Sun Feb 22 2015 mpluskal@suse.com
- Clenup spec file with spec-cleaner
- Update project and download url
- Add gpg signature
- Enable checks
* Mon Aug 18 2014 fcrozat@suse.com
- Add obsoletes to baselibs.conf.
* Mon Mar 31 2014 pgajdos@suse.com
- update to 1.11:
  * Improved dump format.
  * New function: gdbm_count.
  * New utilities: gdbm_dump and gdbm_load.
  * gdbmtool
* Wed Mar  6 2013 jengelh@inai.de
- Specify exact version requirements for build
* Mon Mar  4 2013 pgajdos@suse.com
- buildrequire makeinfo
* Wed Feb  6 2013 cfarrell@suse.com
- license update: GPL-3.0+
  See the COPYING file
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Mon Sep 24 2012 i@marguerite.su
- update baselibs.conf
* Sun Sep 23 2012 i@marguerite.su
- update to 1.10
  * fully internationalized. available in Finnish
    ,German, Japanese, Polish and Ukrainian
  * Support for close-on-exec flag in gdbm_open (see GDBM_CLOEXEC in the docs)
  * Improved testgdbm command system
  * Fixed Bug #150, should handle read(2) returning less data
  * Fixed Bug #151, uses uninitialized memory content
  * Fixed handling of NDBM databases in read-only mode
- add zh_CN translation
  * manually add. will submit to upstream.
- drop gdbm-1.8.3.diff (Patch0)
  * seems this one is useless.
- regenerate and change gdbm-1.8.3-no-build-date.patch (Patch4) to
  gdbm-no-build-date.patch
  * its an universal solution no matter the version.
- drop gdbm-protoize_dbm_headers.patch (Patch1)
  * upstream fixed.
- drop gdbm-prototype_static_functions.patch (Patch2)
  * upstream fixed.
- drop gdbm-fix_testprogs.patch (Patch3)
  * upstream code change. now useless.
* Fri Mar  2 2012 andrea.turrini@gmail.com
- Fixed typos in gdbm.spec descriptions
* Tue Feb  7 2012 coolo@suse.com
- fix baselibs.conf
* Sun Feb  5 2012 jengelh@medozas.de
- Name library package according to shlib policy
- Update description, source text from GNU homepage
* Sun Feb  5 2012 jengelh@medozas.de
- Remove redundant tags/sections
- Replace /usr/%%_lib by simpler %%_libdir
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Sep 21 2010 pgajdos@suse.cz
- fixed wrong header of dbmclose() in our
  protoize_dbm_headers.patch [bnc#640700]
* Sun Aug 29 2010 cristian.rodriguez@opensuse.org
- DO not include a compile date in the resulting binaries
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sun Dec 13 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Sun Dec  6 2009 jengelh@medozas.de
- Enable parallel building for gdbm package
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Mon Nov 24 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Feb 28 2008 pth@suse.de
- Add ANSI prototypes to dbm.h and ndbm.h (protected by macros)
- Provide full prototype for static function.
- Fix test* apps by including appropriate headers and calling
  fgets instead of gets.
* Wed Dec 26 2007 crrodriguez@suse.de
- both libgdbm.la and libgdbm_compat.la had empty dependency_libs
  and has been removed.
- fix library-without-ldconfig-post* errors
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Aug 24 2005 kukuk@suse.de
- Don't reuse old temporary files in gdbm_reorganize [#105763]
* Mon Aug 30 2004 schwab@suse.de
- Fix uses of libtool.
* Fri Nov 21 2003 kukuk@suse.de
- Compile with no execstack
- Build as normal user
* Wed Jul  2 2003 kukuk@suse.de
- Remove man from buildsystem
* Mon May 12 2003 kukuk@suse.de
- Use defattr
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Feb  7 2003 ro@suse.de
- added install_info macros
* Fri Jan 10 2003 kukuk@suse.de
- Use fcntl instead of flock for locking
* Mon Dec  2 2002 kukuk@suse.de
- Update to gdbm 1.8.3 (lot of bug fixes)
* Fri Aug  9 2002 kukuk@suse.de
- Fix requires for gdbm-devel [Bug #17543]
* Thu May 30 2002 olh@suse.de
- use aclocal + autoreconf --force --install, fix for ppc64
* Wed Apr 17 2002 kukuk@suse.de
- Remove gdbm 1.7.3
* Tue Dec 11 2001 froh@suse.de
- the Makefile.in of gdbm 1.7 is missing @libdir@, instead of patching
  that we follow sparc64 and ia64 and just ommit gdbm 1.7 on s390x.
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Fri Oct 27 2000 kukuk@suse.de
- Create devel subpackage
* Mon Sep 25 2000 kukuk@suse.de
- Use BuildRoot
* Thu Jun  1 2000 kukuk@suse.de
- Add group tag
* Tue Apr  4 2000 kukuk@suse.de
- Add ltconfig fix
* Tue Apr  4 2000 kukuk@suse.de
- Add automake to need for build
* Mon Apr  3 2000 bk@suse.de
- s390 team added config.{sub,guess} update macros for s390
* Thu Feb  3 2000 schwab@suse.de
- Update config.{guess,sub} to latest version.
* Fri Jan 21 2000 kukuk@suse.de
- Move /usr/{info,man} -> /usr/share/{info,man}
* Mon Oct 18 1999 kukuk@suse.de
- gdbm 1.8.0: Fix memory leak
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 27 1999 kukuk@suse.de
- Fix file list
* Thu Aug 26 1999 kukuk@suse.de
- Add libgdbm 1.8.0 as default
* Mon Jun 28 1999 kukuk@suse.de
- Add libndbm.so and libndbm.a link
* Mon Mar  1 1999 ro@suse.de
- added ndbm.h for glibc-2.1
* Mon Feb 22 1999 ro@suse.de
- link explicitly with -lc
* Fri Dec 18 1998 ro@suse.de
- respect alpha in specfile
* Mon Dec  7 1998 ro@suse.de
- pack ndbm.h only for libc5
* Mon Oct 20 1997 ro@suse.de
- ready for autobuild
* Thu Jan  2 1997 florian@suse.de
- add ndbm.h header files
